==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/user/messages/it/base.php <==
<?php

return [
    '<strong>Followers</strong>' => 'Persone che <strong>mi seguono</strong>',
    '<strong>Following</strong>' => 'Persone che <strong>seguo io</strong>',
    '<strong>Group</strong> members - {group}' => 'Membri del <strong>Gruppo</strong>- {group}',
    '<strong>Member</strong> in these spaces' => '<strong>Partecipa</strong> in questi space',
    '<strong>Member</strong> of these Spaces' => '<strong>Membro</strong> di questi Spazi',
    '<strong>People</strong>' => '<strong>Persone</strong>',
    '<strong>User</strong> tags' => 'Tag dell\'<strong>utente</strong>',
    'All' => 'Tutti',
    'Any' => 'Qualsiasi',
    'Auth Mode' => 'Modalità autenticato',
    'Basic Settings' => 'Impostazioni base',
    'Change Email' => 'Modifica email',
    'Change Password' => 'Modifica password',
    'Change Username' => 'Cambia nome utente',
    'Confirm new password' => 'Conferma nuova password',
    'Connect account' => 'Collega account',
    'Connected Accounts' => 'Account collegati',
    'Connected accounts' => 'Account collegati',
    'Created at' => 'Creato il',
    'Created by' => 'Creato da',
    'Current password' => 'Password attuale',
    'Currently in use' => 'Al momento in uso',
    'Default Group' => 'Gruppo predefinito',
    'Default Space' => 'Space predefinito',
    'Delete' => 'Cancella',
    'Delete Account' => 'Elimina Account',
    'Description' => 'Descrizione',
    'Disconnect account' => 'Disconnetti account',
    'Email' => 'Email',
    'Enable Notifications' => 'Attivare le notifiche',
    'Find people by their profile data or user tags' => 'Trova le persone in base ai dati del loro profilo o ai tag utente',
    'Follow' => 'Segui',
    'Followers' => 'Mi seguono',
    'Following' => 'Seguo io',
    'Following (User)' => 'Seguito (Utente)',
    'Force password change upon first login' => 'Forza la modifica della password al primo accesso',
    'Force password change upon next login' => 'Forza la modifica della password al prossimo accesso',
    'Friends' => 'Amici',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Qui è possibile connettersi a provider di servizi esterni per utilizzare i servizi esterni come autenticazione integrata.',
    'Invite by email' => 'Invita via email',
    'Invited by' => 'Invitato da',
    'Language' => 'Lingua',
    'Last Login' => 'Ultimo accesso',
    'Manager' => 'Responsabile',
    'Missing E-Mail Attribute from AuthClient.' => 'Attributo E-Mail mancante da AuthClient.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Attributo ID AuthClient mancante da AuthClient.',
    'Modules' => 'Moduli',
    'Name' => 'Nome',
    'New password' => 'Nuova password',
    'No results found!' => 'Nessun risultato trovato!',
    'No users found.' => 'Nessun utente trovato.',
    'Notifications' => 'Notifiche',
    'Password' => 'Password',
    'Password changed' => 'Password cambiata',
    'Password needs to be at least {chars} characters long.' => 'La password deve contenere almeno {chars} caratteri.',
    'Password recovery' => 'Recupera password',
    'Pending Requests' => 'Richieste in sospeso',
    'People' => 'Persone',
    'Permission' => 'Permessi',
    'Profile' => 'Profilo',
    'Profile posts only' => 'Solo post del profilo',
    'Register now and participate!' => 'Registrati adesso e partecipa!',
    'Search...' => 'Cerca...',
    'Security' => 'Sicurezza',
    'Settings' => 'Impostazioni',
    'Show At Registration' => 'Mostra durante la registrazione',
    'Show all content' => 'Mostra tutti i contenuti',
    'Sign in' => 'Accedi',
    'Sign in / up' => 'Accedi/Iscriviti',
    'Sign up' => 'Accedi',
    'Sign up now' => 'Accedi ora',
    'Sort order' => 'Ordinamento',
    'Source' => 'Sorgente',
    'Status' => 'Stato',
    'Tags' => 'Tag',
    'Try other keywords or remove filters.' => 'Prova altre parole chiave o rimuovi i filtri.',
    'Unknown user status!' => 'Stato utente sconosciuto!',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Tentativi di accesso non riusciti dall\'ultimo accesso: {failedLoginAttemptsCount}',
    'Updated at' => 'Aggiornato il',
    'Updated by' => 'Aggiornato da',
    'User' => 'Utente',
    'User Group' => 'Gruppo di utenti',
    'User has been invited.' => 'L\'utente è stato invitato',
    'Username' => 'Username',
    'Username contains invalid characters.' => 'Il nome utente contiene caratteri non validi',
    'Visibility' => 'Visibilità',
    'Visible' => 'Visibile',
    'Welcome to %appName%' => 'Benvenuto in %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Benvenuto in %appName%. Per favore clicca sul pulsante qui sotto per procedere con la registrazione.',
    'Whenever a user follows another user.' => 'Ogni volta che un utente segue un altro utente.',
    'You got an invite' => 'Hai ricevuto un invito',
    'You\'re not registered.' => 'Non sei registrato',
    'You\'ve been invited to join {space} on {appName}' => 'Sei stato invitato a partecipare a {space} su {appName}.',
    'Your account is disabled!' => 'Il tuo account è disabilitato!',
    'Your account is not approved yet!' => 'Il tuo account non è ancora stato approvato!',
    'Your are already logged in! - Logout first!' => 'Sei già loggato! - Prima disconnettiti!',
    'Your new password must not be equal your current password!' => 'Non puoi scegliere una password uguale alla precedente.',
    'invited you to join {name}.' => 'ti ha invitato ad unirti a {name}.',
    'invited you to join {space} on {name}.' => 'ti ha invitato ad unirti a {space} su {name}.',
    'or' => 'o',
    'Did you forget your password?' => '',
    'If this wasn\'t you, you can disregard this message.' => '',
    'Invite by link' => '',
    'Invite new people' => '',
    'It looks like you clicked on an invalid password reset link. Please try again.' => '',
    'Offline' => '',
    'Online' => '',
    'The secure link has been copied in your clipboard!' => '',
    'You tried registering an account with %appName%, but already have an account associated with this email address.' => '',
];

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/user/messages/it/base.php <==
<?php

return [
    '<strong>Followers</strong>' => 'Persone che <strong>mi seguono</strong>',
    '<strong>Following</strong>' => 'Persone che <strong>seguo io</strong>',
    '<strong>Member</strong> in these spaces' => '<strong>Partecipa</strong> in questi space',
    '<strong>Member</strong> of these Spaces' => '<strong>Membro</strong> di questi Spazi',
    '<strong>People</strong>' => '<strong>Persone</strong>',
    '<strong>User</strong> tags' => 'Tag dell\'<strong>utente</strong>',
    'All' => 'Tutti',
    'Allow users to mention you' => 'Consenti agli utenti di menzionarti',
    'Allows access to your about page with personal information' => 'Permetti l\'accesso alla tua pagina con informazioni personali',
    'Any' => 'Qualsiasi',
    'Auth Mode' => 'Modalità autenticato',
    'Basic Settings' => 'Impostazioni base',
    'Change Email' => 'Modifica email',
    'Change Password' => 'Modifica password',
    'Change Username' => 'Cambia nome utente',
    'Confirm new password' => 'Conferma nuova password',
    'Connect account' => 'Collega account',
    'Connected Accounts' => 'Account collegati',
    'Connected accounts' => 'Account collegati',
    'Created at' => 'Creato il',
    'Created by' => 'Creato da',
    'Current password' => 'Password attuale',
    'Currently in use' => 'Al momento in uso',
    'Default Group' => 'Gruppo predefinito',
    'Default Space' => 'Space predefinito',
    'Delete' => 'Cancella',
    'Delete Account' => 'Elimina Account',
    'Description' => 'Descrizione',
    'Disconnect account' => 'Disconnetti account',
    'Edit' => 'modifica',
    'Email' => 'Email',
    'Enable Notifications' => 'Attivare le notifiche',
    'Find people by their profile data or user tags' => 'Trova le persone in base ai dati del loro profilo o ai tag utente',
    'Follow' => 'Segui',
    'Followers' => 'Mi seguono',
    'Following' => 'Seguo io',
    'Following (User)' => 'Seguito (Utente)',
    'Force password change upon first login' => 'Forza la modifica della password al primo accesso',
    'Force password change upon next login' => 'Forza la modifica della password al prossimo accesso',
    'Friends' => 'Amici',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Qui è possibile connettersi a provider di servizi esterni per utilizzare i servizi esterni come autenticazione integrata.',
    'Invite by email' => 'Invita via email',
    'Invite by link' => 'Invita tramite link',
    'Invite new people' => 'Invitare nuove persone',
    'Invited by' => 'Invitato da',
    'Language' => 'Lingua',
    'Last Login' => 'Ultimo accesso',
    'Mentioning' => 'Menzionare',
    'Missing E-Mail Attribute from AuthClient.' => 'Attributo E-Mail mancante da AuthClient.',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Attributo ID AuthClient mancante da AuthClient.',
    'Modules' => 'Moduli',
    'My Account' => 'Il mio Account',
    'Name' => 'Nome',
    'New password' => 'Nuova password',
    'No results found!' => 'Nessun risultato trovato!',
    'No users found.' => 'Nessun utente trovato.',
    'Notifications' => 'Notifiche',
    'Password' => 'Password',
    'Password changed' => 'Password cambiata',
    'Password needs to be at least {chars} characters long.' => 'La password deve contenere almeno {chars} caratteri.',
    'Password recovery' => 'Recupera password',
    'Pending Requests' => 'Richieste in sospeso',
    'People' => 'Persone',
    'Permission' => 'Permessi',
    'Profile' => 'Profilo',
    'Profile posts only' => 'Solo post del profilo',
    'Register now and participate!' => 'Registrati adesso e partecipa!',
    'Search...' => 'Cerca...',
    'Security' => 'Sicurezza',
    'Settings' => 'Impostazioni',
    'Show At Registration' => 'Mostra durante la registrazione',
    'Show all content' => 'Mostra tutti i contenuti',
    'Sign in' => 'Accedi',
    'Sign in / up' => 'Accedi/Iscriviti',
    'Sign up' => 'Accedi',
    'Sign up now' => 'Accedi ora',
    'Sort order' => 'Ordinamento',
    'Source' => 'Sorgente',
    'Status' => 'Stato',
    'Tags' => 'Tag',
    'The secure link has been copied in your clipboard!' => 'Il link sicuro è stato copiato negli appunti!',
    'Try other keywords or remove filters.' => 'Prova altre parole chiave o rimuovi i filtri.',
    'Unknown user status!' => 'Stato utente sconosciuto!',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Tentativi di accesso non riusciti dall\'ultimo accesso: {failedLoginAttemptsCount}',
    'Updated at' => 'Aggiornato il',
    'Updated by' => 'Aggiornato da',
    'User' => 'Utente',
    'User Group' => 'Gruppo di utenti',
    'User has been invited.' => 'L\'utente è stato invitato',
    'Username' => 'Username',
    'Username contains invalid characters.' => 'Il nome utente contiene caratteri non validi',
    'View your about page' => 'Vedi la tua pagina di informazioni',
    'Visibility' => 'Visibilità',
    'Visible' => 'Visibile',
    'Welcome to %appName%' => 'Benvenuto in %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Benvenuto in %appName%. Per favore clicca sul pulsante qui sotto per procedere con la registrazione.',
    'Whenever a user follows another user.' => 'Ogni volta che un utente segue un altro utente.',
    'You got an invite' => 'Hai ricevuto un invito',
    'You\'re not registered.' => 'Non sei registrato',
    'You\'ve been invited to join {space} on {appName}' => 'Sei stato invitato a partecipare a {space} su {appName}.',
    'Your account is disabled!' => 'Il tuo account è disabilitato!',
    'Your account is not approved yet!' => 'Il tuo account non è ancora stato approvato!',
    'Your are already logged in! - Logout first!' => 'Sei già loggato! - Prima disconnettiti!',
    'Your new password must not be equal your current password!' => 'Non puoi scegliere una password uguale alla precedente.',
    'invited you to join {name}.' => 'ti ha invitato ad unirti a {name}.',
    'invited you to join {space} on {name}.' => 'ti ha invitato ad unirti a {space} su {name}.',
    'or' => 'o',
    'Advanced Profile Search' => '',
    'Block user' => '',
    'Did you forget your password?' => '',
    'Group Manager(s)' => '',
    'If this wasn\'t you, you can disregard this message.' => '',
    'It looks like you clicked on an invalid password reset link. Please try again.' => '',
    'Offline' => '',
    'Online' => '',
    'The Group Manager can approve pending registrations of this group.' => '',
    'The user has been blocked for you.' => '',
    'The user has been unblocked for you.' => '',
    'Unblock user' => '',
    'You tried registering an account with %appName%, but already have an account associated with this email address.' => '',
];
